# API keps for reuse

## ragnostic-gemini-thebeast

gcloud services api-keys get-key-string d6055b77-86ae-4c98-9f9d-be9facde6436 --project=gen-lang-client-0425831460

keyString: AIzaSyAeXZVgWlQSTgzX7cGGe-MQvyBmgHG_Puw


## ragnostic-gemini-macos
gcloud services api-keys get-key-string 5bbe9b70-79e6-4aa6-b78d-da904501b21a --project=gen-lang-client-0425831460

keyString: AIzaSyA8_LDTIf3_WSjMEr9mnG5TDjPUOIV4B9I


# Undo Deletion

## Xlence

nicholasgrundl~/projects/gcptest $ gcloud projects delete xlence-436516
Your project will be deleted: [xlence-436516]

Do you want to continue (Y/n)?  y

Deleted [https://cloudresourcemanager.googleapis.com/v1/projects/xlence-436516].

You can undo this operation for a limited period by running the command below.
    $ gcloud projects undelete xlence-436516

See https://cloud.google.com/resource-manager/docs/creating-managing-projects for information on shutting down projects.


## Consulting tea

nicholasgrundl~/projects/gcptest $ gcloud projects delete tribal-quest-420719
Your project will be deleted: [tribal-quest-420719]

Do you want to continue (Y/n)?  y

Deleted [https://cloudresourcemanager.googleapis.com/v1/projects/tribal-quest-420719].

You can undo this operation for a limited period by running the command below.
    $ gcloud projects undelete tribal-quest-420719

See https://cloud.google.com/resource-manager/docs/creating-managing-projects for information on shutting down projects.

## AI Evals course

nicholasgrundl~/projects/gcptest $ gcloud projects delete ai-evals-course
Your project will be deleted: [ai-evals-course]

Do you want to continue (Y/n)?  y

Deleted [https://cloudresourcemanager.googleapis.com/v1/projects/ai-evals-course].

You can undo this operation for a limited period by running the command below.
    $ gcloud projects undelete ai-evals-course

See https://cloud.google.com/resource-manager/docs/creating-managing-projects for information on shutting down projects.


## Ragnostic
nicholasgrundl~/projects/gcptest $ gcloud projects delete gen-lang-client-0425831460
Your project will be deleted: [gen-lang-client-0425831460]

Do you want to continue (Y/n)?  y

Deleted [https://cloudresourcemanager.googleapis.com/v1/projects/gen-lang-client-0425831460].

You can undo this operation for a limited period by running the command below.
    $ gcloud projects undelete gen-lang-client-0425831460

See https://cloud.google.com/resource-manager/docs/creating-managing-projects for information on shutting down projects.


## Bibliotech
nicholasgrundl~/projects/gcptest $ gcloud projects delete gen-lang-client-0234409365
Your project will be deleted: [gen-lang-client-0234409365]

Do you want to continue (Y/n)?  y

Deleted [https://cloudresourcemanager.googleapis.com/v1/projects/gen-lang-client-0234409365].

You can undo this operation for a limited period by running the command below.
    $ gcloud projects undelete gen-lang-client-0234409365

See https://cloud.google.com/resource-manager/docs/creating-managing-projects for information on shutting down projects.

